==> phpfreechat-5.x-1.0-rc3.tar.gz: phpfreechat/handler.php <==
<?php
// $Id: handler.php,v 1.3.2.8 2007/11/13 11:08:04 owahab Exp $

// Original implementation of locating Drupal root from dursh module by Moshe Weitzman.
define('PHPFREECHAT_DRUPAL_BOOTSTRAP', 'includes/bootstrap.inc');

/**
 * Exhaustive depth-first search to try and locate the Drupal root directory.
 * This makes it possible to run drush from a subdirectory of the drupal root.
 */
function _phpfreechat_locate_root() {
  $path = getcwd();
  // Convert windows paths.
  $path = str_replace('\\','/', $path);
  // Check the current path.
  if (file_exists($path . '/' . PHPFREECHAT_DRUPAL_BOOTSTRAP)) {
    return $path;
  }
  // Move up dir by dir and check each.
  while ($path = _phpfreechat_locate_root_moveup($path)) {
    if (file_exists($path . '/' . PHPFREECHAT_DRUPAL_BOOTSTRAP)) {
      return $path;
    }
  }
  return FALSE;
}

function _phpfreechat_locate_root_moveup($path) {
  if (empty($path)) {
    return FALSE;
  }
  $path = explode('/', $path);
  // Move one directory up.
  array_pop($path);
  return implode($path, '/');
}

/**
 * Bootstrap Drupal.
 */
// Change to Drupal root dir.
chdir(_phpfreechat_locate_root());
// Drupal will probably miscalculate the base_url if we're bootstrapping from 
// handler.php
if (!isset($base_url)) {
  $base_root = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on') ? 'https' : 'http';
  // As $_SERVER['HTTP_HOST'] is user input, ensure it only contains
  // characters allowed in hostnames.
  $base_url = $base_root .= '://'. preg_replace('/[^a-z0-9-:._]/i', '', $_SERVER['HTTP_HOST']);
  // $_SERVER['SCRIPT_NAME'] can, in contrast to $_SERVER['PHP_SELF'], not
  // be modified by a visitor.
  // Also use $_SERVER['HTTP_REFERRER'] to correlate with original bootstrap
  $base_path = explode('/', $_SERVER['HTTP_REFERER']);
  $script_path = explode('/', $_SERVER['SCRIPT_NAME']);
  $base_url .= implode('/', array_intersect($base_path, $script_path));
}
// Bootstrap Drupal.
require_once './includes/bootstrap.inc';
drupal_bootstrap(DRUPAL_BOOTSTRAP_SESSION);
// Initialize configuration variables, using values from settings.php if available.
$conf = variable_init(isset($conf) ? $conf : array());
// Add file.inc for various file functions used in phpfreechat
require_once './includes/file.inc';
// Add common.inc to be able to use drupal_get_path later
require_once './includes/common.inc';
// Add user module to handle user permissions in phpfreechat
require_once drupal_get_path('module', 'user') .'/user.module';
// Starting phpfreechat module
require_once drupal_get_path('module', 'phpfreechat') .'/phpfreechat.module';
// Load global params
$params = phpfreechat_load_params();
// We will need to load the current node
if (!function_exists('arg')) {
  // Use HTTP_REFERER to extract the node ID
  $path = str_replace(array($base_url, '/?q='), '', $_SERVER['HTTP_REFERER']);
  // Get the real path from the current request
  require_once './includes/path.inc';
  $args = explode('/', drupal_get_normal_path($path));
  // Make sure we get nid correctly
  // since drupal_get_normal_path() returns a path with a leading slash
  // in case of not using mod_rewrite
  while ($arg0 != 'node') {
    list($arg0, $nid) = $args;
    array_shift($args);
  }
  $node = db_fetch_object(db_query('SELECT * FROM {node} n INNER JOIN {phpfreechat} pfc ON pfc.nid = n.nid WHERE n.nid = %d', $nid));
  if ($_SERVER['drupal_user']) {
    $user = $_SESSION['drupal_user'];
  }
}
// Prepare params for current node
$params = phpfreechat_prepare_params($params, $node, $user);
// Start/resume a chat room
require_once drupal_get_path('module', 'phpfreechat') .'/phpfreechat/src/phpfreechat.class.php';
$chat = new phpFreeChat($params);
?>

==> phpfreechat-5.x-1.2.tar.gz: phpfreechat/handler.php <==
<?php
// $Id: handler.php,v 1.3.2.11 2008/12/01 02:52:07 permutations Exp $

// Original implementation of locating Drupal root from dursh module by Moshe Weitzman.
define('PHPFREECHAT_DRUPAL_BOOTSTRAP', 'includes/bootstrap.inc');

/**
 * Exhaustive depth-first search to try and locate the Drupal root directory.
 * This makes it possible to run drush from a subdirectory of the drupal root.
 */
function _phpfreechat_locate_root() {
  $path = getcwd();
  // Convert windows paths.
  $path = str_replace('\\','/', $path);
  // Check the current path.
  if (file_exists($path . '/' . PHPFREECHAT_DRUPAL_BOOTSTRAP)) {
    return $path;
  }
  // Move up dir by dir and check each.
  while ($path = _phpfreechat_locate_root_moveup($path)) {
    if (file_exists($path . '/' . PHPFREECHAT_DRUPAL_BOOTSTRAP)) {
      return $path;
    }
  }
  return FALSE;
}

function _phpfreechat_locate_root_moveup($path) {
  if (empty($path)) {
    return FALSE;
  }
  $path = explode('/', $path);
  // Move one directory up.
  array_pop($path);
  return implode($path, '/');
}

/**
 * Bootstrap Drupal.
 */
// Change to Drupal root dir.
$drupal_path = _phpfreechat_locate_root();
chdir($drupal_path);
// Drupal will probably miscalculate the base_url if we're bootstrapping from handler.php
if (!isset($base_url)) {
  $base_root = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on') ? 'https' : 'http';
  // As $_SERVER['HTTP_HOST'] allows user input, ensure it only contains valid characters.
  $base_url = $base_root .= '://'. preg_replace('/[^a-z0-9-:._]/i', '', $_SERVER['HTTP_HOST']);
  // Unlike $_SERVER['PHP_SELF'], $_SERVER['SCRIPT_NAME'] cannot be modified by a visitor.
  $script_path = explode('/', $_SERVER['SCRIPT_NAME']);
  $base_path = explode('/', $drupal_path);
  $base_url .= implode('/', array_intersect($base_path, $script_path));
}
// Bootstrap Drupal.
require_once './includes/bootstrap.inc';
drupal_bootstrap(DRUPAL_BOOTSTRAP_SESSION);
// Initialize configuration variables, using values from settings.php if available.
$conf = variable_init(isset($conf) ? $conf : array());
// Add file.inc for various file functions used in phpfreechat
require_once './includes/file.inc';
// Add common.inc to be able to use drupal_get_path later
require_once './includes/common.inc';
// Add user module to handle user permissions in phpfreechat
require_once drupal_get_path('module', 'user') .'/user.module';
// Starting phpfreechat module
require_once drupal_get_path('module', 'phpfreechat') .'/phpfreechat.module';
// Load global params
$params = phpfreechat_load_params();

// We will need to load the current node
if (!function_exists('arg')) {
  // Use HTTP_REFERER to extract the node ID
  $path = str_replace(array($base_url .'/', '/?q='), '', $_SERVER['HTTP_REFERER']);
  // Get the real path from the current request
  require_once './includes/path.inc';
  $args = explode('/', drupal_get_normal_path($path));
  $node = db_fetch_object(db_query('SELECT * FROM {node} n INNER JOIN {phpfreechat} pfc ON pfc.nid = n.nid WHERE n.nid = %d', $args[1]));
  if ($_SESSION['drupal_user']) {
    $user =& $_SESSION['drupal_user'];
  }
}

// Prepare params for current node
$params = phpfreechat_prepare_params($params, $node, $user);

// Start/resume a chat room
require_once drupal_get_path('module', 'phpfreechat') .'/phpfreechat/src/phpfreechat.class.php';
$chat = new phpFreeChat($params);

?>
